@@ -27,6 +27,25 @@ def saveModel(model, base_name, learn_rate ,attempt):
     model.save_weights(f'{base_name}-{learn_rate}-{attempt}.h5')
     model.save(f'{base_name}_{attempt}.h5')
 
+def imageDataGenerator():
+    """
+    We are not adding a 'rescale' attribute because the data has already been normalized using the 'normalize' function of this class
+
+    Returns train_datagen, val_datagen
+    """
+    from tensorflow.keras.preprocessing.image import ImageDataGenerator
+    train_datagen = ImageDataGenerator(rotation_range=40, 
+                                        width_shift_range=.2,
+                                        height_shift_range=.2,
+                                        shear_range=.2,
+                                        zoom_range=.2,
+                                        horizontal_flip=True,
+                                        fill_mode='nearest')
+    # We do not augment the validation data
+    val_datagen = ImageDataGenerator()
+
+    return train_datagen, val_datagen
+    
 def createDefaultModel(img_size=224, optimizer='adam', loss='binary_crossentropy'):
     try:
         model = Sequential()
